@@ -10,7 +10,9 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_07';
+our $VERSION = '0.29_09';
+$VERSION = eval $VERSION; ## no critic
+
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -159,7 +161,7 @@ sub footer_metajson {
 
 	print "\n";
 
-	say THREE . '}';
+	say THREE . '},';
 	my @no_index = $self->no_index;
 	if (@no_index) {
 		say THREE . '"no_index" : {';
@@ -218,7 +220,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_07
+version: 0.29_09
 
 =head1 DESCRIPTION
 
