@@ -8,8 +8,9 @@ use PPI;
 use Data::Printer;    # caller_info => 1;
 use Try::Tiny;
 
-use version;
-our $VERSION = '0.29_07';
+our $VERSION = '0.29_09';
+$VERSION = eval $VERSION; ## no critic
+
 use constant {BLANK => q{ }, TRUE => 1, FALSE => 0, NONE => q{}, TWO => 2,
 	THREE => 3,};
 
@@ -439,13 +440,7 @@ sub _module_names_ppi_sl {
 					$version_string =~ s/(?:['|"])//g;
 					next if $version_string !~ m/\A[\d|v]/;
 
-
-					try {
-						version->parse($version_string)->is_lax;
-					}
-					catch {
-						$version_string = 0 if $_;
-					};
+					$version_string = version::is_lax($version_string) ? $version_string : 0;
 
 					warn 'found version_string - ' . $version_string if $self->debug;
 					try {
@@ -480,7 +475,7 @@ includes, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_07
+version: 0.29_09
 
 
 =head1 METHODS
