@@ -5,13 +5,15 @@ use Moo::Role;
 requires qw( ppi_document debug format xtest _process_found_modules develop );
 
 use PPI;
-use Try::Tiny 0.12;
+use Try::Tiny;
 use Data::Printer {caller_info => 1, colored => 1,};
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
-use version;
-our $VERSION = '0.29_07';
+
+our $VERSION = '0.29_09';
+$VERSION = eval $VERSION; ## no critic
+
 use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 
 
@@ -95,12 +97,7 @@ sub xtests_use_ok {
 												$version_string =~ s/['|"]$//;
 												next if $version_string !~ m/\A[\d|v]/;
 
-												try {
-													version->parse($version_string)->is_lax;
-												}
-												catch {
-													$version_string = 0 if $_;
-												};
+												$version_string = version::is_lax($version_string) ? $version_string : 0;
 
 												warn 'found version_string - ' . $version_string
 													if $self->debug;
@@ -160,7 +157,7 @@ for methods in use_ok in BEGIN blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_07
+version: 0.29_09
 
 =head1 METHODS
 
